document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">Makron och skripting</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">Allmän information och användning av användargränssnitt </label><ul>\
    <li><a target="_top" href="sv/text/sbasic/shared/main0601.html">Hjälp för LibreOffice Basic</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01000000.html">Programmera med LibreOffice Basic</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/00000002.html">Ordlista för LibreOffice Basic</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01010210.html">Basics</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01020000.html">Syntax</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01050000.html">LibreOffice Basic IDE</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01030100.html">IDE - Översikt</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01030200.html">Basic-redigeringsfönstret</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01050100.html">Bevakare</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/main0211.html">Verktygsraden Makro</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/05060700.html">Makro</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/vbasupport.html">Support for VBA Macros</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">Kommandoreferens</label><ul>\
    <li><a target="_top" href="sv/text/sbasic/shared/01020300.html">Använda procedurer och funktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01020500.html">Bibliotek, moduler och dialogrutor</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">Funktioner, uttryck och operatorer</label><ul>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010000.html">In- och utmatningsfunktioner för bildskärm</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020000.html">In- och utmatningsfunktioner för filer</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030000.html">Datum- och tidsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03050000.html">Felhanteringsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060000.html">Logiska operatorer</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070000.html">Matematiska operatorer</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080000.html">Numeriska funktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090000.html">Styra programkörningen</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100000.html">Variabler</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03040000.html">Basic Constants</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03110000.html">Jämförelseoperatorer</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120000.html">Strängar</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/special_vba_func.html">Exclusive VBA functions</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03130000.html">Andra kommandon</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">Alfabetisk lista över funktioner, uttryck och operatorer</label><ul>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080601.html">Abs Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060100.html">AND Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104200.html">Array Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120101.html">Asc Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120111.html">AscW Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080101.html">Atn Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03130100.html">Beep Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010301.html">Blå funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100100.html">CBool Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120105.html">CByte Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100050.html">CCur Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030116.html">CDateFromUnoDateTime Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030115.html">CDateToUnoDateTime Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030114.html">CDateFromUnoTime Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030113.html">CDateToUnoTime Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030112.html">CDateFromUnoDate Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030111.html">CDateToUnoDate Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030108.html">CDateFromIso Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030107.html">CDateToIso Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100300.html">CDate Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100400.html">CDbl Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100060.html">CDec Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100500.html">CInt Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100600.html">CLng Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100900.html">CSng Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101000.html">CStr Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090401.html">Call Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020401.html">ChDir-uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020402.html">ChDrive-uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090402.html">Choose Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120102.html">Chr Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120112.html">ChrW Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020101.html">Stäng uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100700.html">Const Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120313.html">ConvertFromURL Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120312.html">ConvertToURL Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080102.html">Cos Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03132400.html">CreateObject Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131800.html">CreateUnoDialog Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03132000.html">CreateUnoListener Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131600.html">CreateUnoService Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131500.html">CreateUnoStruct Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03132300.html">CreateUnoValue Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020403.html">CurDir-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100070.html">CVar Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03100080.html">CVErr Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030110.html">DateAdd Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030120.html">DateDiff Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030130.html">DatePart Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030101.html">DateSerial Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030102.html">DateValue Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030301.html">Date Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030103.html">Day Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140000.html">DDB Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090403.html">Declare Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101100.html">DefBool Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101300.html">DefDate Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101400.html">DefDbl Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101500.html">DefInt Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101600.html">DefLng Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03101700.html">DefObj Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102000.html">DefVar Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104300.html">DimArray Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102100.html">Dim Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020404.html">Dir-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090201.html">Do...Loop Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090404.html">End Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03130800.html">Environ Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020301.html">Eof-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104600.html">EqualUnoObjects Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060200.html">Eqv Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03050100.html">Erl Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03050200.html">Err Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03050300.html">Error Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03050000.html">Felhanteringsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090412.html">Exit Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080201.html">Exp Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020405.html">FileAttr-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020406.html">FileCopy Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020407.html">FileDateTime Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020415.html">FileExists Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020408.html">FileLen Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103800.html">FindObject Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103900.html">FindPropertyObject Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080501.html">Fix Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120301.html">Format Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020102.html">FreeFile-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090406.html">Function Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090400.html">Ytterligare uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140001.html">FV Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080300.html">Generera slumptal</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020409.html">GetAttr Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03132500.html">GetDefaultContext Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03132100.html">GetGuiType Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131700.html">GetProcessServiceManager Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131000.html">GetSolarVersion Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03130700.html">GetSystemTicks Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020201.html">Hämta uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090301.html">GoSub...Return Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090302.html">GoTo Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010302.html">Grön funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104400.html">HasUnoInterfaces Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080801.html">Hex Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030201.html">Hour Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090103.html">IIf Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090101.html">If...Then...Else Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060300.html">Imp Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120401.html">InStr Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120411.html">InStrRev Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03160000.html">Input Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010201.html">InputBox-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020202.html">Inmatnings# Uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080502.html">Int Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140002.html">IPmt Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140003.html">IRR Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102200.html">IsArray Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102300.html">IsDate Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102400.html">IsEmpty Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104000.html">IsMissing function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102600.html">IsNull Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102700.html">IsNumeric Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102800.html">IsObject Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104500.html">IsUnoStruct Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120315.html">Join Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020410.html">Kill Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102900.html">LBound Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120302.html">LCase Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120304.html">LSet Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120305.html">LTrim Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120303.html">Left Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120402.html">Len Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103100.html">Let Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020203.html">Radinmatnings # Uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020302.html">Loc-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020303.html">Lof-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080202.html">Log Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120306.html">Mid Function, Mid Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030202.html">Minute Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140004.html">MIRR Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020411.html">MkDir Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070600.html">Mod Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030104.html">Month Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03150002.html">MonthName Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010102.html">MsgBox-Funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010101.html">MsgBox-uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020412.html">Name Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060400.html">Not Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030203.html">Now Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140005.html">NPer Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140006.html">NPV Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080000.html">Numeriska funktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080802.html">Oct Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03050500.html">On Error GoTo ... Resume Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020103.html">Öppna uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103200.html">Option Base Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103300.html">Option Explicit Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103350.html">Option VBASupport Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03104100.html">Optional (in Function Statement)</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060500.html">Or Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140007.html">Pmt Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140008.html">PPmt Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140009.html">PV Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010103.html">Print Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103400.html">Public Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020204.html">Ställ uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010304.html">QB-färg funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140010.html">Rate Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010305.html">RGB-funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120308.html">RSet Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120309.html">RTrim Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080301.html">Randomize Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03102101.html">ReDim Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03010303.html">Röd funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090407.html">Rem Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020104.html">Återställ uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120307.html">Right Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020413.html">RmDir Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080302.html">Rnd Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03170000.html">Round Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030204.html">Second Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020304.html">Sök funktion</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020305.html">Sök uttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090102.html">Select...Case Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020414.html">SetAttr Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103700.html">Set Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080701.html">Sgn Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03130500.html">Shell Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080103.html">Sin Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140011.html">SLN Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120201.html">Space Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120314.html">Split Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080401.html">Sqr Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080400.html">Beräkningar av kvadratrot</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103500.html">Static Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090408.html">Stop Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120403.html">StrComp Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120103.html">Str Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120412.html">StrReverse Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120202.html">String Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090409.html">Sub Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090410.html">Switch Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03140012.html">SYD Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080104.html">Tan Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030205.html">TimeSerial Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030206.html">TimeValue Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030302.html">Time Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030303.html">Timer Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03080100.html">Trigonometriska funktioner</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120311.html">Trim Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131300.html">TwipsPerPixelX Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03131400.html">TwipsPerPixelY Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090413.html">Type Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103600.html">TypeName Function; VarType Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03103000.html">UBound Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120310.html">UCase Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03120104.html">Val Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03130600.html">Wait Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030105.html">WeekDay Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03150001.html">WeekdayName Function [VBA]</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090203.html">While...Wend Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03090411.html">With Statement</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03020205.html">Skrivuttryck</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03060600.html">XOR Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03030106.html">Year Function</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070100.html">"-" Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070200.html">"*" Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070300.html">"+" Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">Avancerade grundläggande bibliotek</label><ul>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_formwizard.html">FORMWIZARD Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_gimmicks.html">GIMMICKS Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_schedule.html">SCHEDULE Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_script.html">SCRIPTBINDINGLIBRARY Library</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/03/lib_template.html">TEMPLATE Library</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">Guider</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/macro_recording.html">Spela in ett makro</a></li>\
    <li><a target="_top" href="sv/text/sbasic/guide/control_properties.html">Ändra egenskaper för kontroller i dialogredigeraren</a></li>\
    <li><a target="_top" href="sv/text/sbasic/guide/insert_control.html">Skapa kontroller i dialogredigeraren</a></li>\
    <li><a target="_top" href="sv/text/sbasic/guide/sample_code.html">Programmeringsexempel för kontroller i dialogredigeraren</a></li>\
    <li><a target="_top" href="sv/text/sbasic/guide/show_dialog.html">Öppna en dialogruta med hjälp av programkod</a></li>\
    <li><a target="_top" href="sv/text/sbasic/guide/create_dialog.html">Skapa en dialogruta i Basic</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01030400.html">Strukturera bibliotek och moduler</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01020100.html">Använda variabler</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01020200.html">Använda objekt</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01030300.html">Felsöka Basic-program</a></li>\
    <li><a target="_top" href="sv/text/sbasic/shared/01040000.html">Händelsedrivna makron</a></li>\
    <li><a target="_top" href="sv/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">Kalkylark (Calc)</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">Allmän information och användning av användargränssnitt </label><ul>\
    <li><a target="_top" href="sv/text/scalc/main0000.html">Välkommen till LibreOffice Calc-hjälpen</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0503.html">LibreOffice Calc-funktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/keyboard.html">Kortkommandon (tillgänglighet i LibreOffice Calc)</a></li>\
    <li><a target="_top" href="sv/text/scalc/04/01020000.html">Kortkommandon för tabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/05/02140000.html">Felkoder i LibreOffice Calc</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060112.html">Tillägg för programmering i LibreOffice Calc</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/main.html">Instruktioner till LibreOffice Calc</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">Kommando- och menyreferens</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">Menyer</label><ul>\
    <li><a target="_top" href="sv/text/scalc/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0101.html">Arkiv</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0102.html">Redigera</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0103.html">Visa</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0104.html">Infoga</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0105.html">Format</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0116.html">Blad</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0112.html">Data</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0106.html">Verktyg</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0107.html">Fönster</a></li>\
    <li><a target="_top" href="sv/text/shared/main0108.html">Hjälp</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">Verktygsrader</label><ul>\
    <li><a target="_top" href="sv/text/scalc/main0200.html">Verktygsrader</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0202.html">Verktygsraden Formatering</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0203.html">Verktygsraden Egenskaper för ritobjekt</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0205.html">Verktygsraden Textformatering</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0206.html">Formelrad</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0208.html">Statusrad</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0210.html">Verktygsraden Förhandsgranskning</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0214.html">Verktygsraden Bild</a></li>\
    <li><a target="_top" href="sv/text/scalc/main0218.html">Verktygsraden Verktyg</a></li>\
    <li><a target="_top" href="sv/text/shared/main0201.html">Standardrad</a></li>\
    <li><a target="_top" href="sv/text/shared/main0212.html">Verktygsraden Tabelldata</a></li>\
    <li><a target="_top" href="sv/text/shared/main0213.html">Verktygsraden Formulär</a></li>\
    <li><a target="_top" href="sv/text/shared/main0214.html">Verktygsraden Sökningsutkast</a></li>\
    <li><a target="_top" href="sv/text/shared/main0226.html">Verktygsraden Formulärdesign</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">Funktionstyper och operatorer</label><ul>\
    <li><a target="_top" href="sv/text/scalc/01/04060000.html">Funktionsguiden</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060100.html">Funktioner per kategori</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060107.html">Matrisfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060120.html">Bithanteringsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060101.html">Databasfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060102.html">Datum- och tidsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060103.html">Finansfunktioner del ett</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060119.html">Finansfunktioner del två</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060118.html">Finansfunktioner del tre</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060104.html">Informationsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060105.html">Logiska funktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060106.html">Matematiska funktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060108.html">Statistikfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060181.html">Statistikfunktioner del ett</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060182.html">Statistikfunktioner del två</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060183.html">Statistikfunktioner del tre</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060184.html">Statistikfunktioner del fyra</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060185.html">Statistikfunktioner del fem</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060109.html">Kalkylbladsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060110.html">Textfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060111.html">Tilläggsfunktioner</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060115.html">Tilläggsfunktioner, lista över analysfunktioner del ett</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060116.html">Tilläggsfunktioner, Lista över analysfunktioner del två</a></li>\
    <li><a target="_top" href="sv/text/scalc/01/04060199.html">Operatorer i LibreOffice Calc</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/userdefined_function.html">Användardefinierade funktioner</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">Öppna, spara, importera och exportera</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/webquery.html">Infoga externa data i tabeller (WebQuery)</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/html_doc.html">Spara och öppna tabeller i HTML</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/csv_formula.html">Importera och exportera textfiler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">Formatering</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/text_rotate.html">Rotera text</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/text_wrap.html">Skriva text på flera rader</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/text_numbers.html">Formatera tal som text</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/super_subscript.html">Upphöjd/nedsänkt text</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/row_height.html">Ändra radhöjd eller kolumnbredd</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellstyle_conditional.html">Tillämpa villkorlig formatering</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellstyle_minusvalue.html">Markera negativa tal</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellstyle_by_formula.html">Tilldela format med formler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/integer_leading_zero.html">Skriva tal med inledande nollor</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/format_table.html">Formatera kalkylblad</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/format_value.html">Formatera tal med decimaler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/value_with_name.html">Namnge celler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/table_rotate.html">Rotera tabeller (transponera)</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/rename_table.html">Byta namn på tabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/year2000.html">19xx/20xx år</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/rounding_numbers.html">Använda avrundade tal</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/currency_format.html">Celler i valutaformat</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/autoformat.html">Använda autoformat på tabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/note_insert.html">Infoga och redigera kommentarer</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/design.html">Välja teman för tabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/fraction_enter.html">Mata in bråk</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">Filtrering och sortering</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/filters.html">Använda filter</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/specialfilter.html">Filter: använda specialfilter</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/autofilter.html">Använda Autofilter</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/sorted_list.html">Använda sorteringslistor</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">Utskrifter</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/print_title_row.html">Skriva ut rader eller kolumner på varje sida</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/print_landscape.html">Skriva ut tabeller i liggande format</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/print_details.html">Skriva ut tabellinformation</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/print_exact.html">Definiera antal sidor som ska skrivas ut</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">Dataområden</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/database_define.html">Definiera databasområden</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/database_filter.html">Filtrera cellområden</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/database_sort.html">Sortera data</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">Pivottabell</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot.html">Pivottabell</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot_createtable.html">Skapa pivottabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot_deletetable.html">Ta bort pivottabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot_edittable.html">Redigera pivottabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot_filtertable.html">Filtrera pivottabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot_tipps.html">Välja var pivottabellen placeras</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/datapilot_updatetable.html">Uppdatera pivottabeller</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">Pivotdiagram</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/pivotchart_filter.html">Filtering Pivot Charts</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/pivotchart_update.html">Pivot Chart Update</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/pivotchart_delete.html">Deleting Pivot Charts</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">Scenarier</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/scenario.html">Använda scenarier</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">Referenser</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/relativ_absolut_ref.html">Adresser och referenser, absoluta och relativa</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellreferences.html">Referera till en cell i ett annat dokument</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellreferences_url.html">Referenser till andra tabeller och referera till URL-adresser</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellreference_dragdrop.html">Referera till celler genom att dra och släppa</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/address_auto.html">Identifiera namn och adressering</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">Visning, markering, kopiering</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/table_view.html">Ändra tabellvyer</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/formula_value.html">Visa formler eller värden</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/line_fix.html">Fixera rader eller kolumner som rubriker</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/multi_tables.html">Navigera genom tabellflikar</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/edit_multitables.html">Kopiera till flera tabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cellcopy.html">Kopiera bara synliga celler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/mark_cells.html">Markera flera celler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">Formler och beräkningar</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/formulas.html">Beräkna med formler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/formula_copy.html">Kopiera formler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/formula_enter.html">Ange formler</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/formula_value.html">Visa formler eller värden</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/calculate.html">Beräkna i kalkylblad</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/calc_date.html">Beräkna med datum och tid</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/calc_series.html">Beräkna serier automatiskt</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/calc_timevalues.html">Beräkna tidsskillnader</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/matrixformula.html">Skriva matrisformler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">Skydd</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/cell_protect.html">Skydda celler från ändringar</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/cell_unprotect.html">Ta bort skydd från celler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">Diverse</label><ul>\
    <li><a target="_top" href="sv/text/scalc/guide/auto_off.html">Deaktivera automatiska ändringar</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/consolidate.html">Konsolidera data</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/goalseek.html">Använda målsökning</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/multioperation.html">Använda flera operationer</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/multitables.html">Använda flera tabeller</a></li>\
    <li><a target="_top" href="sv/text/scalc/guide/validity.html">Validera cellinnehåll</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">Grafer och diagram</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">Allmän information</label><ul>\
    <li><a target="_top" href="sv/text/schart/main0000.html">Diagram i LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/schart/main0503.html">Diagramfunktioner i LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/schart/04/01020000.html">Kortkommandon för diagram</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice installation</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/ms_doctypes.html">Ändra associationen till dokumenttyper i Microsoft Office</a></li>\
    <li><a target="_top" href="sv/text/shared/01/profile_safe_mode.html">Felsäkert läge</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">Vanliga hjälpavsnitt</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">Allmän information</label><ul>\
    <li><a target="_top" href="sv/text/shared/main0400.html">Kortkommandon</a></li>\
    <li><a target="_top" href="sv/text/shared/00/00000005.html">Allmän ordlista</a></li>\
    <li><a target="_top" href="sv/text/shared/00/00000002.html">Ordlista med Internet-termer</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/accessibility.html">Tillgänglighet i LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/keyboard.html">Kortkommandon (tillgänglighet i LibreOffice)</a></li>\
    <li><a target="_top" href="sv/text/shared/04/01010000.html">Allmänna kortkommandon i LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/version_number.html">Versioner och versionsnummer</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice och Microsoft Office</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/ms_user.html">Använda Microsoft Office och LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/microsoft_terms.html">Jämföra termer i Microsoft Office och LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/ms_import_export_limitations.html">Om konvertering av Microsoft Office dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/ms_doctypes.html">Ändra associationen till dokumenttyper i Microsoft Office</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">LibreOffice alternativ</label><ul>\
    <li><a target="_top" href="sv/text/shared/optionen/01000000.html">Alternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010100.html">Användardata</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010200.html">Allmänt</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010300.html">Sökvägar</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010400.html">Lingvistik</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010600.html">Allmänt</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010700.html">Teckensnitt</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010800.html">Visa</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01010900.html">Utskriftsalternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01012000.html">Application Colors</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01013000.html">Tillgänglighet</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/java.html">Avancerat</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/expertconfig.html">Expert Configuration</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/persona_firefox.html">Personalization</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01020000.html">Alternativ för att läsa in/spara</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01030000.html">Internet-alternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01040000.html">Textdokumentalternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01050000.html">Alternativ för HTML dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01060000.html">Alternativ för kalkylblad</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01070000.html">Presentationsalternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01080000.html">Ritalternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01090000.html">Formel</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01110000.html">Diagramalternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01130100.html">VBA-egenskaper</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01130200.html">Microsoft Office</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01140000.html">Språk</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01150000.html">Alternativ för språkinställningar</a></li>\
    <li><a target="_top" href="sv/text/shared/optionen/01160000.html">Alternativ för datakällor</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">Guider</label><ul>\
    <li><a target="_top" href="sv/text/shared/autopi/01000000.html">Guide</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">Brevguiden</label><ul>\
    <li><a target="_top" href="sv/text/shared/autopi/01010000.html">Brevguiden</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">Faxguiden</label><ul>\
    <li><a target="_top" href="sv/text/shared/autopi/01020000.html">Faxguiden</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">Agendaguiden</label><ul>\
    <li><a target="_top" href="sv/text/shared/autopi/01040000.html">Guiden Agenda</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">HTML-exportguide</label><ul>\
    <li><a target="_top" href="sv/text/shared/autopi/01110000.html">HTML-export</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">Dokumentkonverteringsguide</label><ul>\
    <li><a target="_top" href="sv/text/shared/autopi/01130000.html">Dokumentkonverteraren</a></li>\
			</ul></li>\
    <li><a target="_top" href="sv/text/shared/autopi/01150000.html">Guide för Eurokonverteraren</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">Konfigurera LibreOffice</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/configure_overview.html">Konfigurera LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/shared/01/packagemanager.html">Tillägg</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/flat_icons.html">Ändra ikonvyer</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/edit_symbolbar.html">Lägga till knappar på verktygsrader</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/workfolder.html">Ändra arbetskatalog</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/standard_template.html">Ändra standardmallar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_addressbook.html">Registrera en adressbok</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/formfields.html">Infoga och redigera knappar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">Arbeta med användargränssnittet</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/navigator_setcursor.html">Navigera för att snabbt flytta till objekt</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/navigator.html">Navigator för dokumentöversikt</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/autohide.html">Visa, förankra och dölja fönster</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/navpane_on.html">Visa navigationsområdet i hjälpen</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/textmode_change.html">Växla mellan infognings- och överskrivningsläge</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/floating_toolbar.html">Använda verktygsrader</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">Digitala signaturer</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/digital_signatures.html">Om digitala signaturer</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/digitalsign_send.html">Använda digitala signaturer</a></li>\
    <li><a target="_top" href="sv/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
    <li><a target="_top" href="sv/text/shared/01/signexistingpdf.html">Signing Existing PDF</a></li>\
    <li><a target="_top" href="sv/text/swriter/01/addsignatureline.html">Adding Signature Line in Text Documents</a></li>\
    <li><a target="_top" href="sv/text/swriter/01/signsignatureline.html">Signing the Signature Line</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">Utskrift, fax, skicka</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/labels_database.html">Skriva ut adressetiketter</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/print_blackwhite.html">Skriva ut i svartvitt</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/email.html">Skicka dokument som e-post</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/fax.html">Skicka fax och konfigurera LibreOffice för faxmeddelanden</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">Dra och släpp</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop.html">Dra-och-släppa inom ett LibreOffice dokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/dragdroptext.html">Flytta och kopiera text i dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_table.html">Kopiera tabellområden till textdokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_graphic.html">Kopiera grafik mellan dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_fromgallery.html">Kopiera grafik från galleriet</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_beamer.html">Dra-och-släpp med datakällvyn</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">Kopiera och klistra in</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/copy_drawfunctions.html">Kopiera ritobjekt till andra dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_graphic.html">Kopiera grafik mellan dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_fromgallery.html">Kopiera grafik från galleriet</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_table.html">Kopiera tabellområden till textdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">Grafer och diagram</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/chart_insert.html">Infoga diagram</a></li>\
    <li><a target="_top" href="sv/text/schart/main0000.html">Diagram i LibreOffice</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">Öppna, spara, importera, exportera</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/doc_open.html">Öppna dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/import_ms.html">Öppna dokument som sparats med ett annat format</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/doc_save.html">Spara dokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/doc_autosave.html">Spara dokument automatiskt</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/export_ms.html">Spara dokument i andra format</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_dbase2office.html">Importera och exportera data i textformat</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">Länkar och referenser</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/hyperlink_insert.html">Infoga hyperlänkar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/hyperlink_rel_abs.html">Relativa och absoluta länkar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/hyperlink_edit.html">Redigera hyperlänkar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">Spåra dokumentändringar</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/redlining_doccompare.html">Jämföra dokumentversioner</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/redlining_docmerge.html">Koppla versioner</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/redlining_enter.html">Registrera ändringar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/redlining.html">Registrera och visa ändringar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/redlining_accept.html">Godkänna och ignorera ändringar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/redlining_versions.html">Versionshantering</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">Etiketter och visitkort</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/labels.html">Skapa och skriva ut etiketter och visitkort</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">Infoga extern data</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/copytable2application.html">Infoga data från kalkylblad</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/copytext2application.html">Infoga data från textdokument</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/insert_bitmap.html">Infoga, redigera och spara bitmappar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/dragdrop_gallery.html">Lägga till grafik i galleriet</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">Automatiska funktioner</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/autocorr_url.html">Stänga av automatisk URL-igenkänning</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">Att söka och ersätta</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/data_search2.html">Söka med ett formulärfilter</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_search.html">Söka i tabeller och formulärdokument</a></li>\
    <li><a target="_top" href="sv/text/shared/01/02100001.html">Lista med reguljära uttryck</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">Guider</label><ul>\
    <li><a target="_top" href="sv/text/shared/guide/linestyles.html">Tillämpa linjestilar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/text_color.html">Ändra textfärg</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/change_title.html">Ändra ett dokuments rubrik</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/round_corner.html">Skapa runda hörn</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/background.html">Definiera bakgrundsfärger eller bakgrundsgrafik</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/lineend_define.html">Definiera linjeslut</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/linestyle_define.html">Definiera linjestilar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/insert_graphic_drawit.html">Redigera grafiska objekt</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/line_intext.html">Rita linjer i text</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/aaa_start.html">De första stegen</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/gallery_insert.html">Infoga objekt från galleriet</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/space_hyphen.html">Inserting Non-breaking Spaces, Hyphens and Soft Hyphens</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/insert_specialchar.html">Infoga specialtecken</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/tabs.html">Infoga och redigera tabbstopp</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/protection.html">Skydda innehåll i LibreOffice</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/redlining_protect.html">Skydda poster</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/pageformat_max.html">Ange maximalt utskriftsområde på en sida</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/measurement_units.html">Välja måttenheter</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/language_select.html">Välja dokumentspråk</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_tabledefine.html">Tabellutkast</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/numbering_stop.html">Stänga av punktuppställningstecken för enskilda stycken</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">Databasfunktionalitet (Base)</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">Allmän information</label><ul>\
    <li><a target="_top" href="sv/text/shared/explorer/database/main.html">LibreOffice-databas</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/database_main.html">Databasöversikt</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_new.html">Skapa en ny databas</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_tables.html">Arbeta med tabeller</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_queries.html">Arbeta med sökningar</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_forms.html">Arbeta med formulär</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_reports.html">Skapa rapporter</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_register.html">Registrera och radera databaser</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_im_export.html">Importera och exportera data i Base</a></li>\
    <li><a target="_top" href="sv/text/shared/guide/data_enter_sql.html">Köra SQL-kommandon</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">Presentationer och ritningar (Impress/Draw)</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">Allmän information och användning av användargränssnitt </label><ul>\
    <li><a target="_top" href="sv/text/simpress/main0000.html">Välkommen till LibreOffice Impress-hjälpen</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0000.html">Välkommen till LibreOffice Draw-hjälpen</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0503.html">Funktioner i LibreOffice Impress</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0503.html">Funktioner i LibreOffice Draw</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/keyboard.html">Använda kortkommandon i LibreOffice Impress</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/keyboard.html">Snabbkommandon för ritobjekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/04/01020000.html">Kortkommandon för LibreOffice Impress</a></li>\
    <li><a target="_top" href="sv/text/simpress/04/presenter.html">Presenter Console Keyboard Shortcuts</a></li>\
    <li><a target="_top" href="sv/text/sdraw/04/01020000.html">Snabbkommandon för ritobjekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/main.html">Instruktioner för hur du använder LibreOffice Impress</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/main.html">Instruktioner till LibreOffice Draw</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">Kommando- och menyreferens</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">Presentationer (LibreOffice Impress)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">Menyer</label><ul>\
    <li><a target="_top" href="sv/text/simpress/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0101.html">Arkiv</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0102.html">Redigera</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0103.html">Vy</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0104.html">Infoga</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0105.html">Format</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0117.html">Bild</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0114.html">Bildskärmspresentation</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0106.html">Verktyg</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0107.html">Fönster</a></li>\
    <li><a target="_top" href="sv/text/shared/main0108.html">Hjälp</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">Verktygsrader</label><ul>\
    <li><a target="_top" href="sv/text/simpress/main0200.html">Verktygsrader</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0202.html">Raden Linje och fyllning</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0203.html">Verktygsraden Textformatering</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0204.html">Objektraden i Bildvy</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0206.html">Statusraden</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0209.html">Linjaler</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0210.html">Verktygsraden Ritverktyg</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0211.html">Verktygsraden Disposition</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0212.html">Verktygsraden Bildsortering</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0213.html">Verktygsraden Alternativ</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0214.html">Verktygsraden Bild</a></li>\
    <li><a target="_top" href="sv/text/shared/main0201.html">Standardrad</a></li>\
    <li><a target="_top" href="sv/text/shared/main0213.html">Verktygsraden Formulär</a></li>\
    <li><a target="_top" href="sv/text/shared/main0226.html">Verktygsraden Formulärdesign</a></li>\
    <li><a target="_top" href="sv/text/shared/main0227.html">Verktygsraden Redigera punkter</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">Teckningar (LibreOffice Draw)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">Menyer</label><ul>\
    <li><a target="_top" href="sv/text/sdraw/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0101.html">Arkiv</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0102.html">Redigera</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0103.html">Visa</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0104.html">Infoga</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0105.html">Format</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0106.html">Verktyg</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0113.html">Modifiera</a></li>\
    <li><a target="_top" href="sv/text/simpress/main0107.html">Fönster</a></li>\
    <li><a target="_top" href="sv/text/shared/main0108.html">Hjälp</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">Verktygsrader</label><ul>\
    <li><a target="_top" href="sv/text/sdraw/main0200.html">Verktygsrader</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0210.html">Verktygsraden Ritverktyg</a></li>\
    <li><a target="_top" href="sv/text/sdraw/main0213.html">Verktygsraden Alternativ</a></li>\
    <li><a target="_top" href="sv/text/shared/main0201.html">Standardrad</a></li>\
    <li><a target="_top" href="sv/text/shared/main0213.html">Verktygsraden Formulär</a></li>\
    <li><a target="_top" href="sv/text/shared/main0226.html">Verktygsraden Formulärdesign</a></li>\
    <li><a target="_top" href="sv/text/shared/main0227.html">Verktygsraden Redigera punkter</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">Öppna, spara, importera och exportera</label><ul>\
    <li><a target="_top" href="sv/text/simpress/guide/html_export.html">Spara en presentation i HTML-format</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/html_import.html">Importera HTML-sidor till presentationer</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/palette_files.html">Läser in färg-, gradient- och skrafferingslistor</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/animated_gif_save.html">Exportera animationer i GIF-format</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/table_insert.html">Infoga kalkylblad på bilder</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/graphic_insert.html">Infoga grafik</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/page_copy.html">Kopiera bilder från andra presentationer</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">Formatering</label><ul>\
    <li><a target="_top" href="sv/text/simpress/guide/palette_files.html">Läser in färg-, gradient- och skrafferingslistor</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/line_arrow_styles.html">Läs in linje- och pilstilar</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/color_define.html">Definiera egna färger</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/gradient.html">Skapa gradientfyllningar</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/eyedropper.html">Byta ut färger</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/align_arrange.html">Placera, justera och fördela objekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/background.html">Ändra bakgrundsfyllningen för en sida</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/footer.html">Lägga till ett sidhuvud eller sidfot i alla bilder</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/masterpage.html">Applying a Slide Design to a Master Slide</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/move_object.html">Flytta objekt</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">Utskrifter</label><ul>\
    <li><a target="_top" href="sv/text/simpress/guide/printing.html">Skriva ut presentationer</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/print_tofit.html">Anpassa utskriften till ett visst pappersformat</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">Effekter</label><ul>\
    <li><a target="_top" href="sv/text/simpress/guide/animated_gif_save.html">Exportera animationer i GIF-format</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/animated_objects.html">Animera objekt i presentationsbilder</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/animated_slidechange.html">Animerade bildväxlingar</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/cross_fading.html">Tona över två objekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/animated_gif_create.html">Skapa animerade GIF-bilder</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">Objekt, grafik och bitmappar</label><ul>\
    <li><a target="_top" href="sv/text/sdraw/guide/combine_etc.html">Kombinera objekt och skapa former</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/draw_sector.html">Rita sektorer och segment</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/duplicate_object.html">Duplicera objekt</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/rotate_object.html">Rotera objekt</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/join_objects3d.html">Samla ihop 3D-objekt</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/join_objects.html">Förbinda linjer</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/text2curve.html">Konvertera texttecken till ritobjekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/vectorize.html">Konvertera bitmapbilder till vektorgrafik</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/3d_create.html">Konvertera 2D-objekt till kurvor, polygoner och 3D-objekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/line_arrow_styles.html">Läs in linje- och pilstilar</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/line_draw.html">Rita kurvor</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/line_edit.html">Redigera kurvor</a></li>\
    <li><a target="_top" href="sv/text/sdraw/guide/graphic_insert.html">Infoga grafik</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/table_insert.html">Infoga kalkylblad på bilder</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/move_object.html">Flytta objekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/select_object.html">Markera underliggande objekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/orgchart.html">Skapa ett flödesschema</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">Grupper och lager</label><ul>\
    <li><a target="_top" href="sv/text/sdraw/guide/groups.html">Gruppera objekt</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/layers.html">Om nivåer</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/layer_new.html">Infoga nivåer</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/layer_tipps.html">Arbeta med nivåer</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/layer_move.html">Flytta objekt till en annan nivå</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">Text i presentationer och teckningar</label><ul>\
    <li><a target="_top" href="sv/text/sdraw/guide/text_enter.html">Lägga till text</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/text2curve.html">Konvertera texttecken till ritobjekt</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">Visning</label><ul>\
    <li><a target="_top" href="sv/text/simpress/guide/arrange_slides.html">Ändra bildordningen</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/change_scale.html">Zooma med tangentbordet</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">Bildspel</label><ul>\
    <li><a target="_top" href="sv/text/simpress/guide/show.html">Visar bilderna</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/individual.html">Skapa en anpassad presentation</a></li>\
    <li><a target="_top" href="sv/text/simpress/guide/rehearse_timings.html">Visa en presentation med tidtagning</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">Formler (Math)</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">Allmän information och användning av användargränssnitt </label><ul>\
    <li><a target="_top" href="sv/text/smath/main0000.html">Välkommen till LibreOffice Math-hjälpen</a></li>\
    <li><a target="_top" href="sv/text/smath/main0503.html">Funktioner i LibreOffice Math</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/main.html">Instruktioner till LibreOffice Math</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/keyboard.html">Genvägar (tillgänglighet i LibreOfficeMath)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">Kommando- och menyreferens</label><ul>\
    <li><a target="_top" href="sv/text/smath/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="sv/text/smath/main0200.html">Verktygsrader</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">Arbeta med formler</label><ul>\
    <li><a target="_top" href="sv/text/smath/guide/align.html">Justera formeldelar manuellt</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/attributes.html">Ändra standardattribut</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/brackets.html">Sammanfoga formeldelar i en parentes</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/comment.html">Skriva kommentarer</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/newline.html">Infoga radbrytningar</a></li>\
    <li><a target="_top" href="sv/text/smath/guide/parentheses.html">Infoga parentes</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">Textdokument (Writer)</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">Allmän information och användning av användargränssnitt </label><ul>\
    <li><a target="_top" href="sv/text/swriter/main0000.html">Välkommen till LibreOffice Writer-hjälpen</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0503.html">Funktioner i LibreOffice Writer</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/main.html">Instruktioner för hur du använder LibreOffice Writer</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/resize_navigator.html">Förankra och ändra storlek på fönster</a></li>\
    <li><a target="_top" href="sv/text/swriter/04/01020000.html">Kortkommandon för LibreOffice Writer</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/words_count.html">Räknar ord</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/keyboard.html">Använda kortkommandon (tillgänglighet i LibreOffice Writer)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">Kommando- och menyreferens</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">Menyer</label><ul>\
    <li><a target="_top" href="sv/text/swriter/main0100.html">Menyer</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0101.html">Arkiv</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0102.html">Redigera</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0103.html">Visa</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0104.html">Infoga</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0105.html">Format</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0115.html">Formatmallar</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0110.html">Tabell</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0120.html">Form Menu</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0106.html">Verktyg</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0107.html">Fönster</a></li>\
    <li><a target="_top" href="sv/text/shared/main0108.html">Hjälp</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">Verktygsrader</label><ul>\
    <li><a target="_top" href="sv/text/swriter/main0200.html">Verktygsrader</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0202.html">Textobjektrad</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0203.html">Bildobjektrad</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0204.html">Verktygsraden Tabell</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0205.html">Verktygsraden Egenskaper för ritobjekt</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0206.html">Verktygsraden Punktuppställningstecken</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0208.html">Statusraden</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0210.html">Förhandsgranskning</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0213.html">Linjaler</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0214.html">Formelrad</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0215.html">Verktygsraden Ram</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0216.html">Verktygsraden OLE-objekt</a></li>\
    <li><a target="_top" href="sv/text/swriter/main0220.html">Verktygsraden Textobjekt</a></li>\
    <li><a target="_top" href="sv/text/shared/main0201.html">Standardrad</a></li>\
    <li><a target="_top" href="sv/text/shared/main0212.html">Verktygsraden Tabelldata</a></li>\
    <li><a target="_top" href="sv/text/shared/main0213.html">Verktygsraden Formulär</a></li>\
    <li><a target="_top" href="sv/text/shared/main0214.html">Verktygsraden Sökningsutkast</a></li>\
    <li><a target="_top" href="sv/text/shared/main0226.html">Verktygsraden Formulärdesign</a></li>\
    <li><a target="_top" href="sv/text/swriter/librelogo/LibreLogo.html">Verktygsraden LibreLogo</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">Skapa textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/text_nav_keyb.html">Navigera och välja med tangentbordet</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_direct_cursor.html">Använda direktmarkören</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">Grafik i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_graphic.html">Infoga grafik</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_graphic_dialog.html">Infoga grafik från en fil</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_graphic_gallery.html">Infoga grafik från galleriet med dra-och-släpp</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_graphic_scan.html">Infoga en skannad bild</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_graphic_fromchart.html">Infoga ett Calc-diagram i ett textdokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_graphic_fromdraw.html">Infoga grafik från LibreOffice Draw eller Impress</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">Tabeller i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/number_date_conv.html">Sätta på och stänga av taligenkänning i tabeller</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/tablemode.html">Ändra rader och kolumner med tangentbordet</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/table_delete.html">Ta bort tabeller eller innehållet i en tabell</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/table_insert.html">Infoga tabeller</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/table_repeat_multiple_headers.html">Upprepa en tabellrubrik på en ny sida</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/table_sizing.html">Ändra storlek på rader och kolumner i en texttabell</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/table_cells.html">Lägga till eller ta bort en rad eller kolumn i en tabell med tangentbordet</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">Objekt i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/anchor_object.html">Placera objekt</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/wrap.html">Skriva text kring objekt</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">Områden och ramar i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/sections.html">Använda områden</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_frame.html">Infoga, redigera och länka textramar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/section_edit.html">Redigera områden</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/section_insert.html">Infoga avsnitt</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">Innehållsförteckning och register</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/chapter_numbering.html">Chapter Numbering</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_userdef.html">Användardefinierade förteckningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_toc.html">Skapa en innehållsförteckning</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_index.html">Skapa sakregister</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_multidoc.html">Förteckningar som täcker flera dokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_literature.html">Skapa en litteraturförteckning</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_delete.html">Redigera eller ta bort poster i förteckningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_edit.html">Uppdatera, redigera och ta bort förteckningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_enter.html">Definiera poster i innehållsförteckningar och andra förteckningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/indices_form.html">Formatera en förteckning</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">Fält i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/fields.html">Om fält</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/fields_date.html">Infoga ett fast eller variabelt datumfält</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/field_convert.html">Konvertera ett fältkommando till text</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">Navigera i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/dragdroptext.html">Flytta och kopiera text i dokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/arrange_chapters.html">Ordna om ett dokument med Navigator</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/hyperlinks.html">Infoga hyperlänkar med Navigator</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/navigator.html">Navigator för textdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">Beräkning i textdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/calculate_multitable.html">Beräkna över tabeller</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/calculate.html">Beräkning i textdokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/calculate_clipboard.html">Beräkna och klistra in resultat av en formel i ett textdokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/calculate_intable.html">Beräkna summan av celler i tabeller</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/calculate_intext.html">Beräkna komplicerade formler i textdokument</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/calculate_intext2.html">Visa resultatet av en tabellberäkning i en annan tabell</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">Formatera textdokument</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">Mallar och formatmallar</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/templates_styles.html">Dokumentmallar och formatmallar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/even_odd_sdw.html">Använd olika sidformatmallar på udda och jämna sidor</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/change_header.html">Skapa en sidformatmall baserad på aktuell sida</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/load_styles.html">Använda formatmallar från andra dokument eller dokumentmallar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/stylist_fromselect.html">Skapa nya formatmallar från markeringar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/stylist_update.html">Uppdatera formatmallar från markeringar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/template_create.html">Skapa en dokumentmall</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/template_default.html">Ändra standardmallen</a></li>\
			</ul></li>\
    <li><a target="_top" href="sv/text/swriter/guide/pageorientation.html">Ändra sidorienteringen (liggande eller stående)</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_capital.html">Ändra skiftläget i en text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/hidden_text.html">Dölja text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/header_pagestyles.html">Definiera olika sidhuvuden och sidfötter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/header_with_chapter.html">Infoga kapitelnamn och kapitelnummer i ett sidhuvud eller en sidfot</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/shortcut_writing.html">Använda textformatering medan du skriver</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/reset_format.html">Återställa teckenattribut</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/stylist_fillformat.html">Använda formatmallar med hjälp av tilldelningsläget</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/wrap.html">Skriva text kring objekt</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_centervert.html">Centrera text på en sida genom att använda en ram</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_emphasize.html">Framhäva text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_rotate.html">Rotera text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/page_break.html">Infoga och radera sidbrytningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/pagestyles.html">Skapa och använda sidformatmallar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/subscript.html">Använda upphöjd eller nedsänkt text</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">Särskilda textelement</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/captions.html">Använda bildtexter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/conditional_text.html">Villkorlig text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/conditional_text2.html">Villkorlig text för sidnumrering</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/fields_date.html">Infoga ett fast eller variabelt datumfält</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/fields_enter.html">Lägga till inmatningsfält</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/footer_nextpage.html">Infoga sidnummer för följande sidor</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/footer_pagenumber.html">Infoga sidnummer i sidfötter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/hidden_text.html">Dölja text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/header_pagestyles.html">Definiera olika sidhuvuden och sidfötter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/header_with_chapter.html">Infoga kapitelnamn och kapitelnummer i ett sidhuvud eller en sidfot</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/fields_userdata.html">Söka användardata i fält eller villkor</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/footnote_usage.html">Infoga och redigera fotnoter eller slutnoter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/footnote_with_line.html">Avstånd mellan fotnoter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/header_footer.html">Om sidhuvuden och sidfötter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/header_with_line.html">Formatera sidhuvuden och sidfötter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/text_animation.html">Animera text</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/form_letters_main.html">Skapa ett standardbrev</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">Automatiska funktioner</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/autocorr_except.html">Lägga till undantag i autokorrigeringslistan</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/autotext.html">Använda autotext</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/auto_numbering.html">Skapa punktlistor eller numrerade listor medan du skriver</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/auto_off.html">Stänga av Autokorrigering</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/auto_spellcheck.html">Automatisk stavningskontroll</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/number_date_conv.html">Sätta på och stänga av taligenkänning i tabeller</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/using_hyphen.html">Avstavning</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">Numrering och listor</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/captions_numbers.html">Lägga till kapitelnummer till bildtexter</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/auto_numbering.html">Skapa punktlistor eller numrerade listor medan du skriver</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/chapter_numbering.html">Chapter Numbering</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_tab_innumbering.html">Ändra kapitelnivån för numrerade listor och punktuppställningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/join_numbered_lists.html">Kombinera numrerade listor</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/numbering_lines.html">Lägga till radnummer</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/numbering_paras.html">Ändra numreringen i en numrerad lista</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/number_sequence.html">Definiera nummersekvenser</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/using_numbered_lists2.html">Lägga till numrering</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/using_numbering.html">Numrering och numreringsformatmallar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/using_numbered_lists.html">Lägga till punktuppställning</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">Stavningskontroll, synonymordbok och språk</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/auto_spellcheck.html">Automatisk stavningskontroll</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/delete_from_dict.html">Ta bort ord från en användarordlista</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/using_thesaurus.html">Synonymordlista</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/spellcheck_dialog.html">Kontrollera stavning och grammatik</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">Problemlösningstips</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/insert_beforetable.html">Infoga text före en tabell i början av en sida</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/jump2statusbar.html">Hoppa till ett visst bokmärke</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">Öppna, spara, importera och exportera</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/send2html.html">Spara textdokument i HTML-format</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/textdoc_inframe.html">Infoga ett helt textdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">Samlingsdokument</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/globaldoc.html">Samlingsdokument och deldokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">Länkar och referenser</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/references.html">Infoga korshänvisningar</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/hyperlinks.html">Infoga hyperlänkar med Navigator</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">Utskrifter</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/printer_tray.html">Välja pappersmagasin på skrivaren</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/print_preview.html">Förhandsgranska en sida före utskrift</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/print_small.html">Skriva ut flera sidor på ett ark</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/pagestyles.html">Skapa och använda sidformatmallar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">Att söka och ersätta</label><ul>\
    <li><a target="_top" href="sv/text/swriter/guide/search_regexp.html">Använda jokertecken vid textsökningar</a></li>\
    <li><a target="_top" href="sv/text/shared/01/02100001.html">Lista med reguljära uttryck</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokument (Writer Web)</label><ul>\
    <li><a target="_top" href="sv/text/shared/07/09000000.html">Webbsidor</a></li>\
    <li><a target="_top" href="sv/text/shared/02/01170700.html">HTML-filter och -formulär</a></li>\
    <li><a target="_top" href="sv/text/swriter/guide/send2html.html">Spara textdokument i HTML-format</a></li>\
	</ul></li></ul>\
';
